// Copyright (C) 1999-2005 Open Source Telecom Corporation.
//  
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software 
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
// 
// As a special exception, you may use this file as part of a free software
// library without restriction.  Specifically, if other files instantiate
// templates or use macros or inline functions from this file, or you compile
// this file and link it with other files to produce an executable, this
// file does not by itself cause the resulting executable to be covered by
// the GNU General Public License.  This exception does not however
// invalidate any other reasons why the executable file might be covered by
// the GNU General Public License.
//
// This exception applies only to the code released under the name GNU
// ccScript.  If you copy code from other releases into a copy of GNU
// ccScript, as the General Public License permits, the exception does
// not apply to the code that you add in this way.  To avoid misleading
// anyone as to the status of such modified files, you must delete
// this exception notice from them.
//
// If you write modifications of your own for GNU ccScript, it is your choice
// whether to permit this exception to apply to your modifications.
// If you do not wish that, delete this exception notice.
//

#include "engine.h"

using namespace std;
using namespace ost;

ScriptProperty *ScriptProperty::first = NULL;

ScriptProperty::ScriptProperty(const char *name)
{
	id = name;
	next = first;
	first = this;
}

ScriptProperty::~ScriptProperty()
{}

long ScriptProperty::getValue(const char *data)
{
	return (long)strlen(data);
}

void ScriptProperty::setValue(char *data, unsigned short len, long value)
{
	snprintf(data, len + 1, "%ld", value);
}

bool ScriptProperty::isProperty(const char *data)
{
	return false;
}

void ScriptProperty::clear(char *data, unsigned size)
{
	data[0] = 0;
}

char ScriptProperty::token(void)
{
	return 0;
}

unsigned ScriptProperty::prec(void)
{
	return 0;
}

void ScriptProperty::adjust(char *data, size_t size, long offset)
{
	return;
}

long ScriptProperty::adjustValue(long value)
{
	return value;
}

ScriptProperty *ScriptProperty::find(const char *name)
{
	ScriptProperty *p = first;

	if(!name)
		return NULL;

	while(p)
	{
		if(!stricmp(p->id, name))
			break;

		p = p->next;
	}
	return p;
}
